OSSP CVS Repository

ossp - Difference in ossp-pkg/as/as-gui/as_assist.cpp versions 1.33 and 1.34
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/as/as-gui/as_assist.cpp 1.33 -> 1.34

--- as_assist.cpp        2002/11/27 22:44:48     1.33
+++ as_assist.cpp        2002/11/27 23:07:38     1.34
@@ -368,17 +368,15 @@
     // Layout controls for table, editing widgets
     m_pMainlayout = new QVBoxLayout(m_pCenframe, TITRAQ_MARGIN, TITRAQ_SPACING, "Mainlayout");  // For layouts
     m_pPackagelayout = new QVBoxLayout(0, 0, TITRAQ_SPACING, "Packagelayout");  // For table
-    m_pDatelayout = new QHBoxLayout(0, 0, TITRAQ_SPACING, "Datelayout");        // For dates
-    m_pTasklayout = new QHBoxLayout(0, 0, TITRAQ_SPACING, "Tasklayout");        // For tasks
+    m_pEditlayout = new QHBoxLayout(0, 0, TITRAQ_SPACING, "Editlayout");        // For edits
 
     // Major sanity check wrapped in one call
-    if (!(m_pMainlayout && m_pPackagelayout && m_pDatelayout && m_pTasklayout))
+    if (!(m_pMainlayout && m_pPackagelayout && m_pEditlayout))
         throw Genexcept("Main window layout creation failed.");
 
     // Specify ordering of the layouts
     m_pMainlayout->addLayout(m_pPackagelayout);
-    m_pMainlayout->addLayout(m_pDatelayout);
-    m_pMainlayout->addLayout(m_pTasklayout);
+    m_pMainlayout->addLayout(m_pEditlayout);
 }
 
 //
@@ -439,7 +437,7 @@
 void Titraqform::setupEditlay(void)
 {
 //    QSpacerItem Pad(TITRAQ_SPACING / 2, 0, QSizePolicy::Fixed);
 //    m_pDatelayout->addWidget(&Pad); // Padd left side of control layout
 
     // Make the date selector
     m_pDateedit = new QDateEdit(m_pCenframe, "Date");
@@ -452,7 +450,7 @@
     m_pDateedit->setAutoAdvance(true);
     m_pDateedit->setSeparator(trUtf8("."));
 
-    m_pDatelayout->addWidget(m_pDateedit);                          // Finally add the date editor
+    m_pEditlayout->addWidget(m_pDateedit);                          // Finally add the date editor
     QToolTip::add(m_pDateedit, trUtf8("Task Date"));
 
     // Whatsthis info for the date editor
@@ -469,7 +467,7 @@
     // Configure attributes
     m_pStarttime->setAutoAdvance(true);
 
-    m_pDatelayout->addWidget(m_pStarttime);                      // Finally add the start editor
+    m_pEditlayout->addWidget(m_pStarttime);                      // Finally add the start editor
     QToolTip::add(m_pStarttime, trUtf8("Task Starting Time"));
 
     // Whatsthis info for the time editor
@@ -483,7 +481,7 @@
     if (m_pEndtime == NULL)                                        // Sanity check
         throw Genexcept("Main window end time creation failed.");  // Spew errors
 
-    m_pDatelayout->addWidget(m_pEndtime);                       // Finally add the end editor
+    m_pEditlayout->addWidget(m_pEndtime);                       // Finally add the end editor
     QToolTip::add(m_pEndtime, trUtf8("Task Ending Time"));
 
     // Whatsthis info for the time editor
@@ -502,7 +500,7 @@
     m_pAmount->setSuffix(trUtf8(" Minutes"));
 //    m_pAmount->setSpecialValueText(trUtf8("In progress"));
 
-    m_pDatelayout->addWidget(m_pAmount);    // Finally add the amount editor
+    m_pEditlayout->addWidget(m_pAmount);    // Finally add the amount editor
     QToolTip::add(m_pAmount, trUtf8("Task Amount"));
 
     // Whatsthis info for the amount editor
@@ -544,7 +542,7 @@
     const char *kszTasktext = "Choose a <em>task account</em> by clicking on "
                               "this box, and choosing whichever item most "
                               "closely resembles your task.";
-    m_pDatelayout->addWidget(m_pTasks); // Finally add the task edit
+    m_pEditlayout->addWidget(m_pTasks); // Finally add the task edit
 
     // Make the Remark line
     m_pRemark = new QLineEdit(m_pCenframe, "Remark");
@@ -556,7 +554,7 @@
     m_pRemark->setFrame(true);
     m_pRemark->setReadOnly(false);
     QToolTip::add(m_pRemark, trUtf8("Remark Line"));
-    m_pDatelayout->addWidget(m_pRemark);    // Finally add the remark line
+    m_pEditlayout->addWidget(m_pRemark);    // Finally add the remark line
 
     // Whatsthis info for the remark line
     const char *kszRemarktext = "Edit the <em>task remarks</em> by clicking on "
@@ -439,7 +437,7 @@
 {
 //    QSpacerItem Pad(TITRAQ_SPACING / 2, 0, QSizePolicy::Fixed);
-//    m_pDatelayout->addWidget(&Pad); // Padd left side of control layout
+//    m_pEditlayout->addWidget(&Pad); // Padd left side of control layout
 
     // Make the date selector

CVSTrac 2.0.1